R

Type Alias R 

pub type R = R<LCD_CTRL_SPEC>;
Register LCD_CTRL reader

Aliased Type

pub struct R { /* private fields */ }

Implementations

Source

impl R

pub fn lcd_hb_front(&self) -> LCD_HB_FRONT_R

Bits 0:10 - It is the horizontal blank front porch of a frame.

pub fn lcd_va_height(&self) -> LCD_VA_HEIGHT_R

Bits 11:20 - It is the vertical active height of a frame.

pub fn lcd_vt_height(&self) -> LCD_VT_HEIGHT_R

Bits 21:30 - It is the vertical total height of a frame.

pub fn lcd_rgb_mode_en(&self) -> LCD_RGB_MODE_EN_R

Bit 31 - 1: Enable RGB mode, and input VSYNC, HSYNC, and DE signals. 0: Disable.