R

Type Alias R 

pub type R = R<STATUSTABLE_SPEC>;
Register STATUSTABLE%s reader

Aliased Type

pub struct R { /* private fields */ }

Implementations

Source

impl R

pub fn from_world(&self) -> FROM_WORLD_R

Bit 0 - This bit is used to confirm world before enter entry 1

pub fn from_entry(&self) -> FROM_ENTRY_R

Bits 1:4 - This filed is used to confirm in which entry before enter entry 1

pub fn current(&self) -> CURRENT_R

Bit 5 - This bit is used to confirm whether the current state is in entry 1