pub type R = R<STATUSTABLE_SPEC>;Expand description
Register STATUSTABLE%s reader
Aliased Type
pub struct R { /* private fields */ }Implementations
Sourceimpl R
impl R
Sourcepub fn from_world(&self) -> FROM_WORLD_R
pub fn from_world(&self) -> FROM_WORLD_R
Bit 0 - This bit is used to confirm world before enter entry 1
Sourcepub fn from_entry(&self) -> FROM_ENTRY_R
pub fn from_entry(&self) -> FROM_ENTRY_R
Bits 1:4 - This filed is used to confirm in which entry before enter entry 1